summaryrefslogtreecommitdiffstats
path: root/desktop-widgets/divelistview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'desktop-widgets/divelistview.cpp')
-rw-r--r--desktop-widgets/divelistview.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/desktop-widgets/divelistview.cpp b/desktop-widgets/divelistview.cpp
index 29dabfa36..1f3a20455 100644
--- a/desktop-widgets/divelistview.cpp
+++ b/desktop-widgets/divelistview.cpp
@@ -199,11 +199,11 @@ void DiveListView::reset()
}
// If items were selected, inform the selection model
-void DiveListView::diveSelectionChanged(const QVector<QModelIndex> &indexes)
+void DiveListView::diveSelectionChanged(const QVector<QModelIndex> &indices)
{
clearSelection();
QItemSelectionModel *s = selectionModel();
- for (const QModelIndex &index: indexes) {
+ for (const QModelIndex &index: indices) {
s->select(index, QItemSelectionModel::Rows | QItemSelectionModel::Select);
// If an item of a not-yet expanded trip is selected, expand the trip.
@@ -420,7 +420,7 @@ void DiveListView::sortIndicatorChanged(int i, Qt::SortOrder order)
if (currentLayout == newLayout) {
sortByColumn(i, order);
} else {
// clear the model, repopulate with new indexes.
std::vector<int> expandedRows;
if(currentLayout == DiveTripModelBase::TREE)
expandedRows = backupExpandedRows();
@@ -420,7 +420,7 @@ void DiveListView::sortIndicatorChanged(int i, Qt::SortOrder order)
sortByColumn(i, order);
} else {
- // clear the model, repopulate with new indexes.
+ // clear the model, repopulate with new indices.
std::vector<int> expandedRows;
if(currentLayout == DiveTripModelBase::TREE)